@@ -24,17 +24,18 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 
-#define WINDOW_WIDTH 64 /* not used */
-#define WINDOW_HEIGHT 64 /* not used */
+#define WINDOW_WIDTH 64
+#define WINDOW_HEIGHT 64
 
 extern Display *display;
 extern int      screen;
-extern Window   rootwindow, window, iconwindow;
-extern Pixmap   on, off;
+extern Window   window, iconwindow;
+extern Pixmap   on, off, numbers, buffer;
 extern GC       gc;
 
 void make_window(void);
 void process_events(void);
+void update_window(void);
 void free_stuff(void);
 
 #endif /* __DOCKAPP_H__ */
