@@ -21,16 +21,10 @@
 #ifndef __WMMEMFREE_H__
 #define __WMMEMFREE_H__
 
-#ifndef TIMER_SECONDS
-#define TIMER_SECONDS 0
-#endif
-
-#ifndef TIMER_MICROSECONDS
-#define TIMER_MICROSECONDS 100000
-#endif
-
 extern int    argc;
 extern char **argv;
 extern int    exitloop;
 
+void stop_timer();
+
 #endif /* __WMMEMFREE_H__ */
